@@ -11,6 +11,9 @@ int main(int c, char *argv[]) {
     msg.set_i(1);
     write_to_file(msg, "data-pos.pbf");
 
+    msg.set_i(200);
+    write_to_file(msg, "data-pos200.pbf");
+
     msg.set_i(std::numeric_limits<uint32_t>::max());
     write_to_file(msg, "data-max.pbf");
 }
